@@ -17,47 +17,53 @@ import boto3
 from delpha_db_manager.utils.aws import start_appflow, start_s3
 import uuid
 import io
+import yaml
 
 
 class CassandraManager:
     """
-    Cassandra Cluster center
-    :param username: String Cassandra username to connect
-    :param password: String password username to connect
+    Cassandra Cluster center to connect thanks to cassandra-driver datastax to AWS Keyspace
     :param pem_file_path: String path of the .pem file to use for 2FA connection
+    :param config_file_path: String path of the .yalk file to use to get credentials
     :param key_space: String session keyspace to set for the Cluster
     """
-    def __init__(self, username, password, pem_file_path, key_space='delpha_actions'):
+    def __init__(self, pem_file_path, config_file_path, key_space='delpha_actions'):
+    
         ssl_context = SSLContext(PROTOCOL_TLSv1_2)
         ssl_context.load_verify_locations(pem_file_path)
         ssl_context.verify_mode = CERT_REQUIRED
-        ssl_context.check_hostname = True
-
-        cassandra_username = os.environ.get('CASSANDRA_USERNAME', username)
-        cassandra_password = os.environ.get('CASSANDRA_PWD', password)
-        cassandra_dc1 = os.environ.get('CASSANDRA_DC1', 'DATACENTER_EU_WEST_1')
-        cassandra_node1 = os.environ.get('CASSANDRA_NODE1', '52.215.22.60')
-        cassandra_node2 = os.environ.get('CASSANDRA_NODE2', '34.254.52.140')
-        cassandra_node3 = os.environ.get('CASSANDRA_NODE3', '34.251.123.6')
+        config = yaml.load(open(config_file_path), Loader=yaml.FullLoader)
+                
+        if os.environ.get('API_TYPE', 'dev') == 'prod':
+            self.config = config['production']
+            key_space = self.config['default_keyspace']
+        else:
+            self.config = config['development']
+            key_space = self.config['default_keyspace']
 
+        cassandra_username = self.config['aws_usr']
+        cassandra_password = self.config['aws_pwd']
+        cluster_nodes = [self.config['aws_zone']]
+        cassandra_dc1 = self.config['aws_dc']
+        port=self.config['port']
+        
         self._cluster = Cluster(
-            [
-                cassandra_node1, cassandra_node2, cassandra_node3
-            ],
+            cluster_nodes,
             load_balancing_policy=DCAwareRoundRobinPolicy(local_dc=cassandra_dc1),
-            port=9042,
+            port=port,
             auth_provider=PlainTextAuthProvider(
                 username=cassandra_username,
                 password=cassandra_password
             ),
             ssl_context=ssl_context
         )
-        self._keyspace = key_space
+        
         self._session = self._cluster.connect(key_space)
         self._session.row_factory = dict_factory
         print('Connected to cluster %s' % self._cluster.metadata.cluster_name)
         for host in self._cluster.metadata.all_hosts():
             print('Datacenter: %s; Host: %s; Rack: %s' % (host.datacenter, host.address, host.rack))
+            
 
     def __del__(self):
         self._cluster.shutdown()
@@ -148,9 +154,12 @@ class SalesforceManager:
         if method == 'get':
             r = requests.request('get', sf_url, headers=self.headers, params=params)
         else:
-            r = requests.request(method, sf_url, headers=self.headers, json=data, params=parameters, timeout=10)
+            r = requests.request(method, sf_url, headers=self.headers, json=data, params=params, timeout=10)
         if r.status_code < 300:
-            return r.json()
+            try:
+                return r.json()
+            except:
+                return r
         else:
             raise Exception('API error when calling %s : %s' % (r.url, r.content))
         
@@ -253,134 +262,3 @@ class SalesforceManager:
             return r.json()
         else:
             raise Exception('API error when calling %s : %s' % (r.url, r.content))
-            
-            
-class AppFlowManager:
-    """
-    Delpha AWS Salesforce data Handler
-    :param key: String AWS key
-    :param secret: String AWS secret
-    :param flow_type: String Flow type to handle ['contact', 'account']
-    :param region: String AWS region 
-    """
-    def __init__(self, key, secret, flow_type, region='us-east-2'):
-        self.s3_handler = start_s3(key, secret, region)
-        self.flow_handler = start_appflow(key, secret, region)
-        self.buckets = None
-        self.settings = {}
-        self.current_settings = {}
-        self._load_settings(flow_type)
-        
-    def _load_settings(self, flow_type):
-        """
-        Load buckets name from AWS
-        """
-        buckets = self.s3_handler.list_buckets()
-        self.buckets = [bucket["Name"] for bucket in buckets["Buckets"]]
-        self.settings = json.loads(self.s3_handler.get_object(Bucket=self.buckets[0], Key = "config/flow_settings.json")["Body"].read().decode('utf-8'))
-        self.current_settings = self.settings[flow_type]
-        self.current_settings["bucket_name"] = self.buckets[0]
-        
-    def set_flow_settings(self, flow_type):
-        """
-        Set flow configuration
-        :param flow_type: String Flow type to be used ['contact', 'account']
-        """
-        self.current_settings = self.settings[flow_type]
-        self.current_settings["bucket_name"] = self.buckets[0]
-        
-    def list_objects(self, bucket_name=None):
-        """
-        List all AWS object in S3 bucket
-        :param bucket_name: String Bucket name to retrieve object from
-        """
-        if not isinstance(bucket_name, str):
-            bucket_name = self.current_settings["bucket_name"]
-        all_objects = self.s3_handler.list_objects(Bucket = bucket_name, Prefix = "Salesforce/Objects/", Delimiter = '/')
-        all_objects = [prefix["Prefix"] for prefix in all_objects["CommonPrefixes"]]
-        return all_objects
-    
-    def list_files(self, bucket_name=None, prefix=None):
-        """
-        List all files available within a bucket, regarding a certain prefix
-        :param bucket_name: String Bucket name to retrieve files from
-        :param prefix: String prefix path to use for file retrieval
-        """
-        if not isinstance(bucket_name, str):
-            bucket_name = self.current_settings["bucket_name"]
-        if not isinstance(prefix, str):
-            prefix = self.current_settings["prefix"]
-        list_obj = []
-        kwargs = {'Bucket': bucket_name}
-        if isinstance(prefix, str):
-                kwargs['Prefix'] = prefix
-        while True:
-                resp = self.s3_handler.list_objects_v2(**kwargs)
-                for obj in resp['Contents']:
-                    key = obj['Key']
-                    if key.startswith(prefix):
-                        list_obj.append(key)
-                try:
-                    kwargs['ContinuationToken'] = resp['NextContinuationToken']
-                except KeyError:
-                    break
-        return list_obj
-    
-    def get_flow_parquet_data(self, bucket_name=None, prefix=None, flow_name=None):
-        """
-        Load Flow data in a pd.DataFrame object
-        :param bucket_name: String Bucket name to retrieve data from
-        :param prefix: String prefix path to use for data retrieval
-        :param flow_name: String Flow name to use
-        """
-        if not isinstance(bucket_name, str):
-            bucket_name = self.current_settings["bucket_name"]
-        if not isinstance(prefix, str):
-            prefix = self.current_settings["prefix"]
-        if not isinstance(flow_name, str):
-            flow_name = self.current_settings["flow_name"]
-        last_flow = self.get_last_flow_id(flow_name)
-        file_folder = prefix+last_flow
-        file_keys = handler.list_files(prefix=file_folder)
-        def pd_read_s3_parquet(key, **args):
-            print(key)
-            obj = self.s3_handler.get_object(Bucket=self.current_settings["bucket_name"], Key=key)
-            return pd.read_parquet(io.BytesIO(obj['Body'].read()), **args)
-        dfs = [pd_read_s3_parquet(key=key) 
-           for key in file_keys]
-        
-        return pd.concat(dfs, ignore_index=True)
-    
-    def start_flow(self, flow_name):
-        """
-        Start a Flow Process
-        :param flow_name: String Name of the flow to trigger
-        """
-        flow_start_response = self.flow_handler.start_flow(flowName=flow_name)
-        flow_status = flow_start_response["ResponseMetadata"]["HTTPStatusCode"]
-        flow_last_execution_record = flow_start_response['executionId']
-        return flow_status, flow_last_execution_record
-    
-    def ensure_spark_format(self, flow_name):
-        """
-        Function to be called on Spark loading to make sure data is in good format
-        :param flow_name: String AppFlow name to be checked
-        """
-        prefix = self.current_settings["prefix"]
-        last_flow = self.get_last_flow_id(flow_name)
-        file_folder = prefix+last_flow
-        file_keys = handler.list_files(prefix=file_folder)
-        if any(".parquet" in s for s in file_keys):
-            return True
-        else:
-            for key in file_keys:
-                self.s3_handler.copy_object(Bucket=self.current_settings['bucket_name'], CopySource="/"+self.current_settings['bucket_name']+"/"+key, Key=file_folder+"/"+str(uuid.uuid4())+".parquet")
-                self.s3_handler.delete_object(Bucket=self.current_settings['bucket_name'], Key=key)
-        return True
-    
-    def get_last_flow_id(self, flow_name):
-        """
-        Get last folder ID for the requested flow
-        :param flow_name: String AppFlow name to be checked
-        """
-        return self.flow_handler.describe_flow_execution_records(flowName=flow_name)["flowExecutions"].pop(0)["executionId"]
